Skip to contents

A character vector of branch names from the sap GitHub repository. Each branch corresponds to a Shiny application example from the Shiny App-Packages book.

Usage

branches

Format

A data frame with 40 rows and 1 column:

branch

Character. The branch name (e.g., "05_roxygen2").